/* This file is part of Kanary <https://bitbucket.org/sirgazil/kanary/>.

Public Domain Dedication.

I, Luis Felipe Lopez Acevedo, dedicate this work to the public domain.
You can copy, modify, distribute and use this work, for any purpose, all
without asking permission. Do whatever you want with it.

Truly yours,

Luis Felipe Lopez Acevedo   
<felipe.lopac@gmail.com>

*/


// VARIABLE DEFINITIONS
var dataSource = ""; // A DOM object generated from syllables.xml


// FUNCTION DEFINITIONS

// Display in the related HTML document a set of syllables in a given writing.
//
// Parameters:
//
// writing   (string) -- indicates hiragana or katakana writing.
// soundType (string) -- any set of sounds defined in syllables.xml.
//
function showSyllables(writing, soundType)
{
    // Define defaults for this function parameters
    soundType = typeof soundType !== "undefined" ? soundType : "basic";
    writing = typeof writing !== "undefined" ? writing : "hiragana";
    
    // Remove all syllables from the syllable selector in the widget
    $("#thumbs").empty();
    
    // Display the syllables indicated
    dataSource.find("sounds[type='" + soundType + "'] syllable").each(function(){
        var syllable = $(this).attr(writing);
      
        $("#thumbs").append("<!-- SYLLABLE -->" + 
                            "<a href='vid/" + syllable + "/" + syllable + ".ogv' " +
                            "title='" + $(this).attr("romaji") + "'>" +
                            "<img class='thumb' " +
                            "src='img/" + syllable + ".png' " +
                            "alt='" + syllable + "'>" +
                            "</a>" +
                            "<!-- END SYLLABLE -->"
                           );
    });
}


// MAIN SCRIPT
$(document).ready(function(){
    
    // Load the japanese syllabary from an XML file
    $.ajax({
        type: "GET",
        url: "syllables.xml",
        dataType: "xml",
        success: function(xml, status){
            dataSource = $(xml);
            showSyllables();
        }
    });


    // Chage the type of writing
    $("select[name='kana'] :selected").live("click", function(){
        writing = $(this).attr("value");
        type = $("select[name='syllables'] :selected").attr("value")
        showSyllables(writing, type);
        return false;
    });
    
    
    // Change the set of syllables
    $("select[name='syllables'] :selected").live("click", function(){
        writing = $("select[name='kana'] :selected").attr("value")
        type = $(this).attr("value");
        showSyllables(writing, type);
        return false;
    });
    

    // Play the animation for the selected syllable.
    $("#thumbs a").live("click", function(){
        var resource = "branding/kanary_intro.ogv";
        $("#viewer").empty();
        
        if ($(this).attr("href") === "vid/void/void.ogv") {
            $("#viewer").append("<video src='" + resource + "' autoplay>" +
                                "<p>Your browser can not play the video" +
                                " natively.</p>" + "<p><a href='" + resource +
                                "'>" + "DOWNLOAD VIDEO</a></p>" +
                                "</video>"
                               );
        }
        else {
            resource = $(this).attr("href");
            $("#viewer").append("<video src='" + resource + "' autoplay " +
                                " controls loop>" +
                                "<p>Your browser can not play the video" +
                                " natively.</p>" + "<p><a href='" + resource +
                                "'>" + "DOWNLOAD VIDEO</a></p>" +
                                "</video>"
                               );
        }
        return false;
    });
});
